@@ -102,7 +102,7 @@ fn parse_attributes(input: &DeriveInput) -> Result<Attributes, Error> {
 ///
 /// Additional arguments can be specified using the `#[check_bytes(...)]` attribute:
 ///
-/// - `bound(...)`: Adds additional bounds to the `CheckBytes` implementation. This can be
+/// - `bound = "..."`: Adds additional bounds to the `CheckBytes` implementation. This can be
 ///   especially useful when dealing with recursive structures, where bounds may need to be omitted
 ///   to prevent recursive type definitions.
 ///
@@ -111,7 +111,7 @@ fn parse_attributes(input: &DeriveInput) -> Result<Attributes, Error> {
 /// its own type, as the implementation of `CheckBytes` for a struct depends on each field type
 /// implementing it as well. Adding the attribute `#[omit_bounds]` to a field will suppress this
 /// trait bound and allow recursive structures. This may be too coarse for some types, in which case
-/// additional type bounds may be required with `bound(...)`.
+/// additional type bounds may be required with `bound = "..."`.
 #[proc_macro_derive(CheckBytes, attributes(check_bytes, omit_bounds))]
 pub fn check_bytes_derive(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
     match derive_check_bytes(parse_macro_input!(input as DeriveInput)) {
@@ -169,7 +169,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                             context
                         ).map_err(|e| StructCheckError {
                             field_name: stringify!(#field),
-                            inner: handle_error(e),
+                            inner: ErrorBox::new(e),
                         })?;
                     }
                 });
@@ -208,7 +208,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                             context
                         ).map_err(|e| TupleStructCheckError {
                             field_index: #i,
-                            inner: handle_error(e),
+                            inner: ErrorBox::new(e),
                         })?;
                     }
                 });
@@ -228,7 +228,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
             Fields::Unit => {
                 quote! {
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #impl_where_clause {
-                        type Error = Unreachable;
+                        type Error = Infallible;
 
                         unsafe fn check_bytes<'a>(value: *const Self, context: &mut __C) -> Result<&'a Self, Self::Error> {
                             Ok(&*value)
@@ -367,7 +367,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                                     variant_name: stringify!(#variant),
                                     inner: StructCheckError {
                                         field_name: stringify!(#name),
-                                        inner: handle_error(e),
+                                        inner: ErrorBox::new(e),
                                     },
                                 })?;
                             }
@@ -389,7 +389,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                                     variant_name: stringify!(#variant),
                                     inner: TupleStructCheckError {
                                         field_index: #i,
-                                        inner: handle_error(e),
+                                        inner: ErrorBox::new(e),
                                     },
                                 })?;
                             }
@@ -441,14 +441,13 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
 
     Ok(quote! {
         const _: () = {
-            use core::marker::PhantomData;
+            use core::{convert::Infallible, marker::PhantomData};
             use bytecheck::{
                 CheckBytes,
                 EnumCheckError,
-                handle_error,
+                ErrorBox,
                 StructCheckError,
                 TupleStructCheckError,
-                Unreachable,
             };
 
             #check_bytes_impl
